EasyExtend.langlets.p4d.p4dbase.P4DAttributes

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dbase :: Class P4DAttributes |
[hide private]
[frames] | no frames]

# Class P4DAttributes

    object --+
             |
          dict --+
                 |
                P4DAttributes

Instance Methods | [hide private]
Inherited from `dict`: `__cmp__`, `__contains__`, `__delitem__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__gt__`, `__hash__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setitem__`, `clear`, `copy`, `fromkeys`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values` Inherited from `object`: `__delattr__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`